@@ -7,7 +7,7 @@
 # Date: 2010.03.23
 #
 # File: espeakcaller.py
-# Version: 0.3
+# Version: 0.4
 # 
 # Special thanks to: 
 #    Original eSpeak project: http://espeak.sourceforge.net/
@@ -42,46 +42,57 @@ class eSpeakCaller(QtGui.QMainWindow):
     
     # Load settings.
     def loadsettings(self):
-        cfgTmp = os.path.expanduser(cfgFileUI)
-        if os.path.exists(cfgTmp): 
-            tmpStr = ""
-            pdFile = open(cfgTmp, 'r')
-            
-            tmpStr = pdFile.readline().strip() # Unknown caller name
-            self.ui.lineUnCaller.setText(tmpStr)
+        try:
+            cfgTmp = os.path.expanduser(cfgFileUI)
+            if os.path.exists(cfgTmp): 
+                tmpStr = ""
+                pdFile = open(cfgTmp, 'r')
                 
-            tmpStr = pdFile.readline().strip() # Spoken language
-            self.ui.comboLang.setCurrentIndex(int(tmpStr))
+                tmpStr = pdFile.readline().strip() # Unknown caller name
+                self.ui.lineUnCaller.setText(tmpStr)
+                    
+                tmpStr = pdFile.readline().strip() # Spoken language
+                self.ui.comboLang.setCurrentIndex(int(tmpStr))
+                    
+                tmpStr = pdFile.readline().strip() # Additional parameters
+                self.ui.lineAParams.setText(tmpStr)
+                    
+                tmpStr = pdFile.readline().strip() # Spoken line
+                self.ui.lineSay.setText(tmpStr)
                 
-            tmpStr = pdFile.readline().strip() # Additional parameters
-            self.ui.lineAParams.setText(tmpStr)
+                tmpStr = str(pdFile.readline().strip()) # Volume
+                self.ui.sliVolume.setValue(int(tmpStr))
                 
-            tmpStr = pdFile.readline().strip() # Spoken line
-            self.ui.lineSay.setText(tmpStr)
-            
-            tmpStr = pdFile.readline().strip() # Volume
-            self.ui.sliVolume.setValue(int(tmpStr))
-            
-            tmpStr = pdFile.readline().strip() # Pitch
-            self.ui.sliPitch.setValue(int(tmpStr))
-            
-            tmpStr = pdFile.readline().strip() # Speed
-            self.ui.sliSpeed.setValue(int(tmpStr))
-            
-            tmpStr = pdFile.readline().strip() # Blocked number
-            self.ui.lineBlCaller.setText(tmpStr)
-            
-            tmpStr = pdFile.readline().strip() # Use nickname
-            if tmpStr == "1":
-                self.ui.checkNickname.setCheckState(-1)
-            else:
-                 self.ui.checkNickname.setCheckState(0)   
-                                 
-            pdFile.close()
-        
-        if os.path.exists(pidFile):
-            self.ui.checkEnabled.setCheckState(-1)
-            
+                tmpStr = str(pdFile.readline().strip()) # Pitch
+                self.ui.sliPitch.setValue(int(tmpStr))
+                
+                tmpStr = str(pdFile.readline().strip()) # Speed
+                self.ui.sliSpeed.setValue(int(tmpStr))
+                
+                tmpStr = pdFile.readline().strip() # Blocked number
+                self.ui.lineBlCaller.setText(tmpStr)
+                
+                tmpStr = pdFile.readline().strip() # Use nickname
+                if tmpStr == "1":
+                    self.ui.checkNickname.setCheckState(-1)
+                else:
+                     self.ui.checkNickname.setCheckState(0)   
+                                     
+                tmpStr = pdFile.readline().strip() # Repeat option
+                if tmpStr == "1":
+                    self.ui.checkRepeat.setCheckState(-1)
+                else:
+                    self.ui.checkRepeat.setCheckState(0)   
+                tmpStr = pdFile.readline().strip() # Repeat option
+                self.ui.sliRepeat.setValue(int(tmpStr))
+                pdFile.close()
+          
+            if os.path.exists(pidFile):
+                self.ui.checkEnabled.setCheckState(-1)
+        except Exception, errtxt:
+            print errtxt
+            pass
+                        
         
     # Save settings
     def SaveSettings(self):
@@ -106,8 +117,12 @@ class eSpeakCaller(QtGui.QMainWindow):
         if self.ui.checkNickname.isChecked():
             pdFile.write("1" + '\n')
         else:
-             pdFile.write("0" + '\n')
-                     
+            pdFile.write("0" + '\n')
+        if self.ui.checkRepeat.isChecked():
+            pdFile.write("1" + '\n')
+        else:
+            pdFile.write("0" + '\n')
+        pdFile.write(str(self.ui.sliRepeat.value()) + '\n')                    
         pdFile.close()
         
         # Save settings for Daemon
@@ -124,7 +139,11 @@ class eSpeakCaller(QtGui.QMainWindow):
             pdFile.write("1" + '\n')
         else:
              pdFile.write("0" + '\n')
-            
+        if self.ui.checkRepeat.isChecked():
+            pdFile.write(str(self.ui.sliRepeat.value()) + '\n') 
+        else:
+            pdFile.write("0" + '\n')
+                    
         pdFile.close()
         
 
@@ -132,7 +151,7 @@ class eSpeakCaller(QtGui.QMainWindow):
     def GeteSpeakCommand(self):
         # Damn eSpeak supports lot of langueages
         sLang=['',' -ven',' -ven-us',' -ven-sc',' -vaf',' -vbs',' -vca',' -vcs',' -vde',' -vel',' -veo',' -ves',' -ves-la',' -vfi',' -vfr',' -vhr',' -vhu',' -vit',' -vku',' -vlv',' -vpl',' -vpt',' -vpt-pt',' -vro',' -vsk',' -vsr',' -vsv',' -vsw',' -vta',' -vtr',' -vzh']
-        tmpCmd = "espeak " + sLang[self.ui.comboLang.currentIndex()] + " "
+        tmpCmd = "espeak -m " + sLang[self.ui.comboLang.currentIndex()] + " "
         tmpCmd = tmpCmd + "-a " + str(self.ui.sliVolume.value()) + " "
         tmpCmd = tmpCmd + "-p " + str(self.ui.sliPitch.value()) + " "
         tmpCmd = tmpCmd + "-s " + str(self.ui.sliSpeed.value()) + " "
@@ -144,8 +163,12 @@ class eSpeakCaller(QtGui.QMainWindow):
        
     # Test eSpeak 
     def slotTest(self):
-        tmpName = self.ui.lineSay.displayText().replace("%name%", "Test")
-        tmpS = self.GeteSpeakCommand().replace("%text%", tmpName)
+        if self.ui.lineBlCaller.displayText() != "":
+            tmpName = self.ui.lineBlCaller.displayText()
+        else:
+            tmpName = self.ui.lineSay.displayText().replace("%name%", "Test")
+
+        tmpS = self.GeteSpeakCommand().replace("%text%", tmpName)#.decode('utf-8')
         #print tmpS
         subprocess.Popen(unicode(tmpS).encode("utf-8"), shell=True)
         
